@@ -55,14 +55,15 @@
      tROOT4 = 271,
      tROOT3 = 272,
      tROOT = 273,
-     tVARIABLE = 274,
-     tSUPNUM = 275,
-     tSUBNUM = 276,
-     BOOLEAN_OPERATOR = 277,
-     PERCENTAGE = 278,
-     UNARY_MINUS = 279,
-     tINVERSE = 280,
-     tIN = 281
+     tFUNCTION = 274,
+     tVARIABLE = 275,
+     tNSUPNUM = 276,
+     tSUPNUM = 277,
+     tSUBNUM = 278,
+     BOOLEAN_OPERATOR = 279,
+     PERCENTAGE = 280,
+     UNARY_MINUS = 281,
+     tIN = 282
    };
 #endif
 /* Tokens.  */
@@ -82,14 +83,15 @@
 #define tROOT4 271
 #define tROOT3 272
 #define tROOT 273
-#define tVARIABLE 274
-#define tSUPNUM 275
-#define tSUBNUM 276
-#define BOOLEAN_OPERATOR 277
-#define PERCENTAGE 278
-#define UNARY_MINUS 279
-#define tINVERSE 280
-#define tIN 281
+#define tFUNCTION 274
+#define tVARIABLE 275
+#define tNSUPNUM 276
+#define tSUPNUM 277
+#define tSUBNUM 278
+#define BOOLEAN_OPERATOR 279
+#define PERCENTAGE 280
+#define UNARY_MINUS 281
+#define tIN 282
 
 
 
@@ -99,7 +101,7 @@ typedef union YYSTYPE
 {
 
 /* Line 1676 of yacc.c  */
-#line 91 "./mp-equation-parser.y"
+#line 174 "./mp-equation-parser.y"
 
   MPNumber int_t;
   int integer;
@@ -108,7 +110,7 @@ typedef union YYSTYPE
 
 
 /* Line 1676 of yacc.c  */
-#line 112 "mp-equation-parser.h"
+#line 114 "mp-equation-parser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
